#ifndef NT2_INCLUDE_FUNCTIONS_FACTOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FACTOR_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/factor.hpp>

#endif
